# pyretrodesign

An implementation of the r-package [retrodesign](https://cran.r-project.org/web/packages/retrodesign/index.html) in python

[Described in Gelman and Carlin, 2014](https://doi.org/10.1177%2F1745691614551642)

## How to install
`pip install pyretrodesign`

## Usage
```python
from pyretrodesign import pyretrodesign
A = 0.4
s = 1
pyretrodesign(A, s)
```

